Module body

Module body 

Message body.

Structs

Body
Message body.
ChunkedBodyDecoder
Decoder for chunked bodies.
ChunkedStream
Wrapper around a Byte stream that will make it chunk-encoded.
FixedSizeBodyDecoder
Message body decoder for fixed-size bodies.
SimpleBodyDecoder
Simple message body decoder that consumes all data until EOF is received.

Traits

MessageBodyDecoder
Common trait for message body decoders. The decoder must not consume any more data once the message body is complete.