ChunkedBodyDecoder

Struct ChunkedBodyDecoder 

pub struct ChunkedBodyDecoder { /* private fields */ }
Decoder for chunked bodies.

It does only a constant amount of allocations. The message body is returned in form of chunks. No chunks will be returned once the body has been successfully decoded.

Implementations

Source

impl ChunkedBodyDecoder

pub fn new(max_line_length: Option<usize>) -> ChunkedBodyDecoder

Create a new decoder for chunked bodies.

Arguments
  • max_line_length - maximum length of a single chunk header line