pub struct FixedSizeBodyDecoder { /* private fields */ }Expand description
Message body decoder for fixed-size bodies.
It does not do any allocations. The message body is returned in form of chunks. No chunks will be returned once a given amount of bytes has been returned.
Implementations
Sourceimpl FixedSizeBodyDecoder
impl FixedSizeBodyDecoder
Sourcepub const fn new(expected: usize) -> FixedSizeBodyDecoder
pub const fn new(expected: usize) -> FixedSizeBodyDecoder
Create a new fixed-size decoder expecting a given number of bytes.