pub fn empty_response(status: Status) -> OutgoingResponseAvailable on crate feature
server only.Expand description
A function returning an empty response with a given status code.
pub fn empty_response(status: Status) -> OutgoingResponseserver only.A function returning an empty response with a given status code.