pub fn see_other<T>(location: T) -> OutgoingResponsewhere
T: Into<HeaderFieldValue>,Available on crate feature
server only.Expand description
A function returning a response with See Other status and a given location.
pub fn see_other<T>(location: T) -> OutgoingResponsewhere
T: Into<HeaderFieldValue>,server only.A function returning a response with See Other status and a given location.