pub struct Error { /* private fields */ }Expand description
Error type.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn from_static_msg(msg: &'static str) -> Self
pub const fn from_static_msg(msg: &'static str) -> Self
Create a new error with a given message.
Sourcepub fn from_other<T>(err: T) -> Self
pub fn from_other<T>(err: T) -> Self
Create a new error from a given custom error.
Sourcepub fn from_other_with_response<T>(err: T) -> Self
Available on crate feature server only.
pub fn from_other_with_response<T>(err: T) -> Self
server only.Create a new error from a given custom error.
Sourcepub fn to_response(&self) -> Option<OutgoingResponse>
Available on crate feature server only.
pub fn to_response(&self) -> Option<OutgoingResponse>
server only.Get error response (if supported).