pub struct ServerHandshake { /* private fields */ }Available on crate features
server and ws only.Expand description
WS server handshake.
Implementations
Sourceimpl ServerHandshake
impl ServerHandshake
Sourcepub fn new(request: IncomingRequest) -> Result<Self, Error>
pub fn new(request: IncomingRequest) -> Result<Self, Error>
Create a new handshake from a given incoming HTTP request.
Sourcepub fn complete(
self,
protocol: Option<&str>,
input_buffer_capacity: usize,
) -> (FutureServer, OutgoingResponse)
pub fn complete( self, protocol: Option<&str>, input_buffer_capacity: usize, ) -> (FutureServer, OutgoingResponse)
Complete the WS handshake.
The method will prepare an HTTP response for the client and indicate use of a given sub-protocol.