pub struct ChunkedBodyDecoder { /* private fields */ }Expand description
Decoder for chunked bodies.
It does only a constant amount of allocations. The message body is returned in form of chunks. No chunks will be returned once the body has been successfully decoded.
Implementations